package zero1hd.polyjet.ui;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.math.Vector3;
import com.badlogic.gdx.scenes.scene2d.Actor;
import com.badlogic.gdx.scenes.scene2d.ui.Button;
import com.badlogic.gdx.scenes.scene2d.ui.ScrollPane;
import com.badlogic.gdx.scenes.scene2d.utils.ChangeListener;

import zero1hd.polyjet.Polyjet;
import zero1hd.polyjet.maps.KeyMap;
import zero1hd.polyjet.ui.builders.GraphicsTable;
import zero1hd.polyjet.ui.builders.SetControls;

public class MoreOptionsPage extends Page {
	private KeyMap keymap;
	private ScrollPane keyBinds;
	private GraphicsTable graphicsSettings;
	private SetControls controlSetter;
	
	public MoreOptionsPage(Polyjet core, final Vector3 targetLocation) {
		keymap = new KeyMap(core);
		
		controlSetter = new SetControls(core.defaultSkin, keymap);
		keyBinds = new ScrollPane(controlSetter, core.defaultSkin);
		keyBinds.setSize(getWidth(), getHeight());
		addActor(keyBinds);
		keyBinds.setVisible(false);
		
		graphicsSettings = new GraphicsTable(core.defaultSkin, core.prefs);
		graphicsSettings.setSize(getWidth(), getHeight());
		addActor(graphicsSettings);
		graphicsSettings.setVisible(false);
		
		Button backArrow = new Button(core.defaultSkin, "arrow-button");
		backArrow.setPosition(30, getHeight()-backArrow.getHeight()-10);
		backArrow.addListener(new ChangeListener() {
			@Override
			public void changed(ChangeEvent event, Actor actor) {
				targetLocation.y = 0.5f*Gdx.graphics.getHeight();
			}
		});
		addActor(backArrow);
	}
	
	public void controlUnselect() {
		controlSetter.unselect();
	}
	
	public void setControlType(byte type) {
		switch (type) {
		case 0:
			keyBinds.setVisible(true);
			graphicsSettings.setVisible(false);
			break;
		case 1:
			keyBinds.setVisible(false);
			graphicsSettings.setVisible(true);
			break;
		}
	}
}
