package zero1hd.polyjet.ui;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Input.Keys;
import com.badlogic.gdx.Preferences;
import com.badlogic.gdx.math.MathUtils;
import com.badlogic.gdx.math.Vector3;
import com.badlogic.gdx.scenes.scene2d.Actor;
import com.badlogic.gdx.scenes.scene2d.InputEvent;
import com.badlogic.gdx.scenes.scene2d.InputListener;
import com.badlogic.gdx.scenes.scene2d.ui.Button;
import com.badlogic.gdx.scenes.scene2d.ui.Label;
import com.badlogic.gdx.scenes.scene2d.ui.ProgressBar;
import com.badlogic.gdx.scenes.scene2d.ui.Slider;
import com.badlogic.gdx.scenes.scene2d.ui.Table;
import com.badlogic.gdx.scenes.scene2d.ui.TextField;
import com.badlogic.gdx.scenes.scene2d.utils.ChangeListener;

import zero1hd.polyjet.Polyjet;
import zero1hd.polyjet.screens.CreativeDebugScreen;

public class OptionsPage extends Page {
	Table optionsTable = new Table();
	private ProgressBar musicVolSlider;
	private ProgressBar fxVolSlider;
	private TextField directoryField;
	private Polyjet core;
	
	private byte goToScreen;
	private Button backSymbol;
	public OptionsPage(final Polyjet core, final Vector3 targetPosition, final MoreOptionsPage moreOptionsPage) {
		this.core = core;
		optionsTable.defaults().padTop(5f).padBottom(5f);
		
		Label optionGeneralTitle = new Label("General", core.defaultSkin, "large-font", core.defaultSkin.getColor("default"));
		optionsTable.add(optionGeneralTitle).left().spaceBottom(10f);
		
		optionsTable.row();
		
		Label musicVolSliderLabel = new Label("Music Volume: ", core.defaultSkin);
		optionsTable.add(musicVolSliderLabel).left();
		musicVolSlider = new Slider(0, 100, 0.1f, false, core.defaultSkin);
		musicVolSlider.setValue(core.prefs.getFloat("music vol", 100f));
		optionsTable.add(musicVolSlider).prefWidth(790);
		final Label musicVolPercentage = new Label(MathUtils.round(musicVolSlider.getValue()) + "%", core.defaultSkin);
		musicVolSlider.addListener(new ChangeListener() {
			@Override
			public void changed(ChangeEvent event, Actor actor) {
				saveOptions(core.prefs);
				musicVolPercentage.setText(MathUtils.round(musicVolSlider.getValue()) + "%");
			}
		});
		optionsTable.add(musicVolPercentage).spaceLeft(12f).left();
		
		optionsTable.row();
		
		Label fxVolSliderLabel = new Label("FX Volume: ", core.defaultSkin);
		optionsTable.add(fxVolSliderLabel).left();
		fxVolSlider = new Slider(0, 100, 1, false, core.defaultSkin);
		fxVolSlider.setValue(core.prefs.getFloat("fx vol", 100f));
		optionsTable.add(fxVolSlider).prefWidth(790);
		final Label fxVolPercentage = new Label(MathUtils.round(fxVolSlider.getValue()) + "%", core.defaultSkin);
		fxVolSlider.addListener(new ChangeListener() {
			@Override
			public void changed(ChangeEvent event, Actor actor) {
				saveOptions(core.prefs);
				fxVolPercentage.setText(MathUtils.round(fxVolSlider.getValue()) + "%");
			}
		});
		
		optionsTable.add(fxVolPercentage).spaceLeft(12f).left();
		
		optionsTable.row();
		
		Label musicDirectoryLabel = new Label("Music Directory: ", core.defaultSkin);
		optionsTable.add(musicDirectoryLabel).left();
		directoryField = new TextField(null, core.defaultSkin);
		directoryField.setText(core.prefs.getString("music dir", System.getProperty("user.home")+System.getProperty("file.separator")+"Music"));
		optionsTable.add(directoryField).prefWidth(810).left();
		
		optionsTable.row();
		
		Label debugCodeLabel = new Label("Debug Code: ", core.defaultSkin);
		optionsTable.add(debugCodeLabel).left();
		final TextField debugCodeField = new TextField(null, core.defaultSkin);
		debugCodeField.addListener(new InputListener() {
			@Override
			public boolean keyUp(InputEvent event, int keycode) {
				if (keycode == Keys.ENTER) {
					Gdx.app.debug("Debug Field", debugCodeField.getText());
					if (debugCodeField.getText().equals("creative")) {
						saveOptions(core.prefs);
						Gdx.app.debug("Debug Field", "going to creative test room...");
						goToScreen = 1;
					}
				}
				return super.keyUp(event, keycode);
			}
		});
		optionsTable.add(debugCodeField).prefWidth(810).left();
		
		optionsTable.top();
		
		
		//Back button
		backSymbol = new Button(core.defaultSkin, "arrow-button");
		backSymbol.addListener(new ChangeListener() {
			@Override
			public void changed(ChangeEvent event, Actor actor) {
				targetPosition.x = 0.5f*Gdx.graphics.getWidth();
			}
		});
		backSymbol.setPosition(10, (getHeight()-backSymbol.getHeight())/2);
		addActor(backSymbol);
		
		optionsTable.setPosition(backSymbol.getX()+ 20 + backSymbol.getWidth(), 0);
		optionsTable.setSize(getWidth()-backSymbol.getWidth()-10-20-10, getHeight());
		addActor(optionsTable);
		
		
		Button keybindSettings = new Button(core.defaultSkin, "arrow-button");
		keybindSettings.addListener(new ChangeListener() {
			@Override
			public void changed(ChangeEvent event, Actor actor) {
				moreOptionsPage.setControlType((byte) 0);
				targetPosition.y = -0.5f*Gdx.graphics.getHeight();
			}
		});
		keybindSettings.setPosition(optionsTable.getWidth()/3, optionsTable.getY());
		addActor(keybindSettings);
		Label controlsSection = new Label("Controls", core.defaultSkin);
		controlsSection.setPosition(keybindSettings.getX()+(keybindSettings.getWidth()-controlsSection.getWidth())/2, keybindSettings.getHeight()+keybindSettings.getY());
		addActor(controlsSection);
		
		Button graphicsSettings = new Button(core.defaultSkin, "arrow-button");
		graphicsSettings.addListener(new ChangeListener() {
			@Override
			public void changed(ChangeEvent event, Actor actor) {
				moreOptionsPage.setControlType((byte) 1);
				targetPosition.y = -0.5f*Gdx.graphics.getHeight();					
			}
		});
		graphicsSettings.setPosition(optionsTable.getWidth()*2/3, optionsTable.getY());
		addActor(graphicsSettings);
		Label graphicsSection = new Label("Graphics", core.defaultSkin);
		graphicsSection.setPosition(graphicsSettings.getX()+(graphicsSettings.getWidth()-graphicsSection.getWidth())/2, graphicsSettings.getHeight()+graphicsSettings.getY());
		addActor(graphicsSection);
	}
	
	public void saveOptions(Preferences prefs) {
		prefs.putFloat("music vol", musicVolSlider.getValue());
		prefs.putFloat("fx vol", fxVolSlider.getValue());
		prefs.putString("music dir", directoryField.getText());
		prefs.flush();
	}
	
	@Override
	public void act(float delta) {
		if (core.assetManager.update() && goToScreen != 0) {
			switch (goToScreen) {
			case 1:
				core.setScreen(new CreativeDebugScreen(core));
			}
			goToScreen = 0;
		}
		super.act(delta);
	}

}
